<?xml version="1.0" encoding="UTF-8"?>

<!--
	* Licensed Materials - Property of IBM
	* 5724-C11, 5724-C13, 5724-D17
	* (C) Copyright IBM Corporation 1997, 2003. All Rights Reserved.
	* US Government Users Restricted Rights- Use, duplication or disclosure
	* restricted by GSA ADP Schedule Contract with IBM Corp.
-->

<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:java="http://xml.apache.org/xslt/java"	
	exclude-result-prefixes="xalan java" >

	<xsl:output method="xml" version="1.0" encoding="UTF-8" standalone="no" indent="yes"/>	
	<xsl:param name="DecisionXML" />

	<!-- 
	***************************************************************************************************************************************************************************
	Global variable definitions
	***************************************************************************************************************************************************************************
	-->

	<!-- *** Format utility variables *** -->

	<xsl:variable name="newline">
	<xsl:text>
	</xsl:text>
	</xsl:variable>	

	<xsl:variable name="objXSLTUtils" select="java:com.ibm.btools.itools.cwconverter.xslt.ext.XSLTUtils.new()"/>	

	<!-- 
	***************************************************************************************************************************************************************************
	Converts the collaboration template from version 4.1.1 to the latest.
	***************************************************************************************************************************************************************************
	-->


	<!-- *** XSLT starts at the root template *** -->
	<xsl:template match="/">
		<!-- *** write the DTD for our root element CollabTemplate *** -->
		<xsl:text disable-output-escaping="yes">
			&lt;!DOCTYPE CollabTemplate [
			&lt;!--
			 Base Elements and Attributes
			-->
			&lt;!ELEMENT Title (#PCDATA)>
			&lt;!ELEMENT Desc (#PCDATA)>
			&lt;!ELEMENT Value (#PCDATA)>
			&lt;!ELEMENT Default (#PCDATA)>
			&lt;!ELEMENT CreateTime (#PCDATA)>
			&lt;!ATTLIST CreateTime Format CDATA #REQUIRED>
			&lt;!ELEMENT ModifyTime (#PCDATA)>
			&lt;!ATTLIST ModifyTime Format CDATA #REQUIRED>
			&lt;!ELEMENT GUICoord EMPTY>
			&lt;!ATTLIST GUICoord X CDATA #REQUIRED>
			&lt;!ATTLIST GUICoord Y CDATA #REQUIRED>
			&lt;!ELEMENT GUICoord2 (GUICoord,GUICoord)>
			&lt;!ELEMENT GUICoords (GUICoord,GUICoord+)>
			&lt;!ELEMENT Color EMPTY>
			&lt;!ATTLIST Color R CDATA #REQUIRED>
			&lt;!ATTLIST Color G CDATA #REQUIRED>
			&lt;!ATTLIST Color B CDATA #REQUIRED>
			&lt;!ELEMENT GUIFont (FaceName,PointSize,Height,Color)>
			&lt;!ATTLIST GUIFont Italic CDATA #REQUIRED>
			&lt;!ATTLIST GUIFont UnderLine CDATA #REQUIRED>
			&lt;!ATTLIST GUIFont StrikeOut CDATA #REQUIRED>
			&lt;!ELEMENT FaceName (#PCDATA)>
			&lt;!ELEMENT PointSize (#PCDATA)>
			&lt;!ELEMENT Height (#PCDATA)>

			&lt;!--
			 Header section
			-->
			&lt;!ELEMENT Header (Title,Desc,CreateTime,ModifyTime)>

			&lt;!--
			 Collaboration Document
			-->
			&lt;!ELEMENT CollabTemplate (Header,TemplateDefinition,GUITemplateDefinition,Scenarios,Messages)>
			&lt;!ATTLIST CollabTemplate Name CDATA #REQUIRED>
			&lt;!ATTLIST CollabTemplate Version CDATA #REQUIRED>
			&lt;!ATTLIST CollabTemplate FormatVersion CDATA #REQUIRED>

			&lt;!--
			 Collaboration Definition section
			-->
			&lt;!ELEMENT TemplateDefinition (Desc,Properties,MinTransactionLevel,Package,GeneratedVars,BusObjRefs)>
			&lt;!ELEMENT MinTransactionLevel EMPTY>
			&lt;!ATTLIST MinTransactionLevel Level (None|Minimum|Best|Stringent) "None">
			&lt;!ELEMENT Package (#PCDATA)>
			&lt;!ELEMENT GeneratedVars (#PCDATA)>
			&lt;!ELEMENT BusObjRefs (BusObjRef)*>
			&lt;!ELEMENT BusObjRef (ConnectorName,Verbs)>
			&lt;!ATTLIST BusObjRef Name CDATA #REQUIRED>
			&lt;!ATTLIST BusObjRef BusObjType CDATA #REQUIRED>
			&lt;!ATTLIST BusObjRef IsRequired (Yes|No) #REQUIRED>
			&lt;!ATTLIST BusObjRef IsConfigured (Yes|No) #REQUIRED>
			&lt;!ELEMENT ConnectorName (#PCDATA)>
			&lt;!ELEMENT Verbs (Verb)*>
			&lt;!ELEMENT Verb (ScenarioName)>
			&lt;!ATTLIST Verb Name CDATA #REQUIRED>
			&lt;!ATTLIST Verb IsSubscribeEvent (Yes|No) #REQUIRED>
			&lt;!ELEMENT ScenarioName (#PCDATA)>

			&lt;!--
			 GUI Collaboration Definition section
			-->
			&lt;!ELEMENT GUITemplateDefinition (GUIProperties,GUIImports,GUIUserSection1,GUIUserSection2,GUIUserSection3,GUIVariables)>
			&lt;!ELEMENT GUIProperties (GeneralProperties?,BOProbeProperties?)>
			&lt;!ELEMENT GeneralProperties (GUIProperty)*>
			&lt;!ELEMENT BOProbeProperties (GUIProperty)*>
			&lt;!ELEMENT GUIProperty (GUIPropertyType,Desc,MaxStringLength,MaxMultipleValues,DefaultValues,PossibleValues)>
			&lt;!ATTLIST GUIProperty Name CDATA #REQUIRED>
			&lt;!ELEMENT GUIPropertyType (#PCDATA)>
			&lt;!ELEMENT MaxStringLength (#PCDATA)>
			&lt;!ELEMENT MaxMultipleValues (#PCDATA)>
			&lt;!ELEMENT DefaultValues (Values,Ranges)>
			&lt;!ELEMENT PossibleValues (Values,Ranges)>
			&lt;!ELEMENT Values (GUIPropertyValue)*>
			&lt;!ELEMENT Ranges (Range)*>
			&lt;!ELEMENT Range (Min,Max)*>
			&lt;!ELEMENT GUIPropertyValue (#PCDATA)>
			&lt;!ELEMENT Min (#PCDATA)>
			&lt;!ELEMENT Max (#PCDATA)>
			&lt;!ELEMENT GUIImports (GUIImport)*>
			&lt;!ELEMENT GUIImport (ImportName,Comment)>
			&lt;!ELEMENT ImportName (#PCDATA)>
			&lt;!ELEMENT Comment (#PCDATA)>
			&lt;!ELEMENT GUIUserSection1 (#PCDATA)>
			&lt;!ELEMENT GUIUserSection2 (#PCDATA)>
			&lt;!ELEMENT GUIUserSection3 (#PCDATA)>
			&lt;!ELEMENT GUIVariables (GUIVariable)*>
			&lt;!ELEMENT GUIVariable (VarType,ObjectType?,VarName,VarValue,FirstStepInit?,VarModifier1,VarModifier2,VarModifier3,Comment)>
			&lt;!ELEMENT VarType (#PCDATA)>
			&lt;!ELEMENT ObjectType (#PCDATA)>
			&lt;!ATTLIST ObjectType NeedsTwoStepInit (Yes|No) #REQUIRED>
			&lt;!ELEMENT FirstStepInit (#PCDATA)>
			&lt;!ELEMENT VarName (#PCDATA)>
			&lt;!ELEMENT VarValue (#PCDATA)>
			&lt;!ELEMENT VarModifier1 (#PCDATA)>
			&lt;!ELEMENT VarModifier2 (#PCDATA)>
			&lt;!ELEMENT VarModifier3 (#PCDATA)>

			&lt;!--
			 Scenario section
			-->
			&lt;!ELEMENT Scenarios (Scenario)*>
			&lt;!ELEMENT Scenario (Header,GUIDefinition,GUIDiagrams,ModelScenario)>
			&lt;!ATTLIST Scenario Name CDATA #REQUIRED>
			&lt;!ATTLIST Scenario Version CDATA #REQUIRED>
			&lt;!ATTLIST Scenario DiagramRef IDREF #REQUIRED>
			&lt;!ATTLIST Scenario DiagramRefGUI IDREF #REQUIRED>
			&lt;!ELEMENT GUIDefinition (Desc,GUIUserSection1,GUIUserSection2,GUIVariables)>

			&lt;!--
			 GUI Diagram section
			-->
			&lt;!ELEMENT GUIDiagrams (GUIDiagram)*>
			&lt;!ELEMENT GUIDiagram (Header,GUIProperties,GUISettings,NodesGUI,LinksGUI,Texts)>
			&lt;!ATTLIST GUIDiagram Name ID #REQUIRED>
			&lt;!ATTLIST GUIDiagram Version CDATA #REQUIRED>
			&lt;!ELEMENT ModelScenario (Diagram)*>

			&lt;!--
			 GUI Diagram Settings section
			-->
			&lt;!ELEMENT GUISettings (DiagramPermission,PageSettings,ComponentView,Grid)>
			&lt;!ELEMENT DiagramPermission EMPTY>
			&lt;!ATTLIST DiagramPermission Value (Yes|No) #REQUIRED>
			&lt;!ELEMENT PageSettings EMPTY>
			&lt;!ATTLIST PageSettings SizeX CDATA #REQUIRED>
			&lt;!ATTLIST PageSettings SizeY CDATA #REQUIRED>
			&lt;!ATTLIST PageSettings BoundVisible (Yes|No) #REQUIRED>
			&lt;!ELEMENT ComponentView EMPTY>
			&lt;!ATTLIST ComponentView Type (Yes|No) #REQUIRED>
			&lt;!ATTLIST ComponentView UIDs (Yes|No) #REQUIRED>
			&lt;!ATTLIST ComponentView Labels (Yes|No) #REQUIRED>
			&lt;!ELEMENT Grid (Color)>
			&lt;!ATTLIST Grid Visible (Yes|No) #REQUIRED>
			&lt;!ATTLIST Grid Snap (Yes|No) #REQUIRED>
			&lt;!ATTLIST Grid SizeX CDATA #REQUIRED>
			&lt;!ATTLIST Grid SizeY CDATA #REQUIRED>

			&lt;!--
			 GUI Node, Link and Text elements section
			-->
			&lt;!ELEMENT NodeLinkGUI (GUIFont)>
			&lt;!ATTLIST NodeLinkGUI UniqIDRef IDREF #REQUIRED>
			&lt;!ELEMENT NodesGUI (NodeGUI)*>
			&lt;!ELEMENT NodeGUI (NodeLinkGUI,GUICoord2,DecisionNode?)>
			&lt;!ATTLIST NodeGUI DiagramRefGUI IDREF #IMPLIED>
			&lt;!ELEMENT LinksGUI (LinkGUI)*>
			&lt;!ELEMENT LinkGUI (NodeLinkGUI,GUICoords,BOProbe?,Connect?,DecisionLink?)>
			&lt;!ELEMENT DecisionLink (Label,Desc)>
			&lt;!ATTLIST DecisionLink UniqID ID #REQUIRED>
			&lt;!ELEMENT BOProbe (BOUnit*)>
			&lt;!ATTLIST BOProbe Name CDATA #REQUIRED>
			&lt;!ATTLIST BOProbe LinkID IDREF #REQUIRED>
			&lt;!ATTLIST BOProbe ActionID IDREF #REQUIRED>
			&lt;!ATTLIST BOProbe To IDREF #REQUIRED>
			&lt;!ELEMENT BOUnit (#PCDATA)>
			&lt;!ATTLIST LinkGUI IsOrthogonal (Yes|No) #REQUIRED>
			&lt;!ELEMENT Texts (Text)*>
			&lt;!ELEMENT Text (TextValue,GUIFont,GUICoord2)>
			&lt;!ELEMENT TextValue (#PCDATA)>

			&lt;!--
			 ModelElement
			-->
			&lt;!ELEMENT ModelElement (Desc)>
			&lt;!ATTLIST ModelElement Version CDATA #REQUIRED>

			&lt;!--
			 ModelStructureElement
			-->
			&lt;!ELEMENT ModelStructureElement (ModelElement)>
			&lt;!ATTLIST ModelStructureElement Name CDATA #REQUIRED>

			&lt;!--
			 ModelActivityElement
			-->
			&lt;!ELEMENT ModelActivityElement (ModelElement,Label)>
			&lt;!ATTLIST ModelActivityElement UniqID ID #REQUIRED>
			&lt;!ELEMENT Label (#PCDATA)>

			&lt;!--
			 Misc - dummy elements
			-->
			&lt;!ELEMENT PseudoState (Node)>
			&lt;!ELEMENT ProcessStep (Node)>

			&lt;!--
			 Diagram
			-->
			&lt;!ELEMENT Diagram (ModelStructureElement,Declaration,DiagramBody)>
			&lt;!ATTLIST Diagram Name ID #REQUIRED>
			&lt;!ATTLIST Diagram Version CDATA #REQUIRED>
			&lt;!ELEMENT Declaration (Section1,Section2)>
			&lt;!ELEMENT Section1 (#PCDATA)>
			&lt;!ELEMENT Section2 (#PCDATA)>
			&lt;!ELEMENT DiagramBody (ModelActivityElement,Nodes,Links)>

			&lt;!--
			 Nodes - note that there can be only one start node
			-->
			&lt;!ELEMENT Node (ModelActivityElement)>
			&lt;!ATTLIST Node UserModified (Yes|No) "No">
			&lt;!ELEMENT Nodes ( (ActionNode|SubMapNode|SubDiagramNode|IteratorNode|ServiceNode|OutboundServiceNode|InboundServiceNode|SuccessEndNode|FailureEndNode|BreakNode|ForkNode|JoinNode)* |
			 (InitialNode, (ActionNode|SubMapNode|SubDiagramNode|IteratorNode|ServiceNode|OutboundServiceNode|InboundServiceNode|SuccessEndNode|FailureEndNode|BreakNode|ForkNode|JoinNode)*) |
			 ( (ActionNode|SubMapNode|SubDiagramNode|IteratorNode|ServiceNode|OutboundServiceNode|InboundServiceNode|SuccessEndNode|FailureEndNode|BreakNode|ForkNode|JoinNode)*,InitialNode) |
			 ( (ActionNode|SubMapNode|SubDiagramNode|IteratorNode|ServiceNode|OutboundServiceNode|InboundServiceNode|SuccessEndNode|FailureEndNode|BreakNode|ForkNode|JoinNode)*,InitialNode, (ActionNode|SubMapNode|SubDiagramNode|IteratorNode|ServiceNode|OutboundServiceNode|InboundServiceNode|SuccessEndNode|FailureEndNode|BreakNode|ForkNode|JoinNode)*))>
			&lt;!ELEMENT CompositeNode (ProcessStep)>
			&lt;!ATTLIST CompositeNode DiagramRef IDREF #REQUIRED>

			&lt;!ELEMENT InitialNode (PseudoState,CorrelationSet*)>
			&lt;!ELEMENT SuccessEndNode (PseudoState)>
			&lt;!ELEMENT FailureEndNode (PseudoState)>
			&lt;!ELEMENT BreakNode (PseudoState)>
			&lt;!ELEMENT ForkNode (PseudoState)>
			&lt;!ELEMENT JoinNode (PseudoState)>
			&lt;!ELEMENT ActionNode (ProcessStep,CodeFragment)>
			&lt;!ELEMENT SubMapNode (ActionNode)>
			&lt;!ATTLIST SubMapNode SubMapName CDATA #REQUIRED>
			&lt;!ATTLIST SubMapNode SubMapType CDATA #REQUIRED>
			&lt;!ELEMENT CodeFragment (#PCDATA)>
			&lt;!ATTLIST CodeFragment Type (Java|XML) #REQUIRED>
			&lt;!ELEMENT ServiceNode (ProcessStep,RegBusObjName,RegBusObjVerb,RegBusObjRefName,CmpBusObjName,CmpBusObjVerb,CmpBusObjRefName,WaitTimeOut,CorrelationSet*)>
			&lt;!ELEMENT RegBusObjName (#PCDATA)>
			&lt;!ELEMENT RegBusObjVerb (#PCDATA)>
			&lt;!ELEMENT RegBusObjRefName (#PCDATA)>
			&lt;!ELEMENT CmpBusObjName (#PCDATA)>
			&lt;!ELEMENT CmpBusObjVerb (#PCDATA)>
			&lt;!ELEMENT CmpBusObjRefName (#PCDATA)>
			&lt;!ELEMENT WaitTimeOut (#PCDATA)>
			&lt;!ATTLIST WaitTimeOut Type (NotUsed|Constant|Parameter|Variable) #REQUIRED>
			&lt;!ELEMENT CorrelationSet (CorrelationAttribute+)>
			&lt;!ATTLIST CorrelationSet IsInit (Yes|No) "No">
			&lt;!ELEMENT CorrelationAttribute (AttributeName,VariableName)>
			&lt;!ELEMENT AttributeName (#PCDATA)>
			&lt;!ELEMENT VariableName (#PCDATA)>
			&lt;!ELEMENT OutboundServiceNode (ServiceNode)>
			&lt;!ATTLIST OutboundServiceNode IsSync CDATA #REQUIRED>
			&lt;!ELEMENT InboundServiceNode (ServiceNode)>
			&lt;!ELEMENT SubDiagramNode (CompositeNode)>
			&lt;!ELEMENT IteratorNode (CompositeNode,IteratorVariable,ThruThisObject,Start,Condition,Increment)>
			&lt;!ATTLIST IteratorNode Type (Attribute|BusObj|Loop) #REQUIRED>
			&lt;!ELEMENT IteratorVariable (#PCDATA)>
			&lt;!ELEMENT ThruThisObject (#PCDATA)>
			&lt;!ELEMENT Start (#PCDATA)>
			&lt;!ELEMENT Condition (#PCDATA)>
			&lt;!ELEMENT Increment (#PCDATA)>
			&lt;!ELEMENT DecisionNode (Label,Desc,DecisionBranches)>
			&lt;!ATTLIST DecisionNode UniqID ID #REQUIRED>
			&lt;!ELEMENT DecisionBranch (Condition,Comment,Label,LinkID)>
			&lt;!ELEMENT DecisionBranches (DecisionBranch,DecisionBranch+)>
			&lt;!ATTLIST DecisionBranch Type (NotUsed|Normal|Default|Exception) #REQUIRED>
			&lt;!ELEMENT LinkID (#PCDATA)>

			&lt;!--
			 Links
			-->
			&lt;!ELEMENT Link (ModelActivityElement,Connect)>
			&lt;!ELEMENT Links (TransitionLink|MessageLink|ExceptionLink)*>
			&lt;!ELEMENT Connect EMPTY>
			&lt;!ATTLIST Connect From IDREF #REQUIRED>
			&lt;!ATTLIST Connect To IDREF #REQUIRED>

			&lt;!ELEMENT TransitionLink (Link,GuardCondition)>
			&lt;!ELEMENT GuardCondition (#PCDATA)>
			&lt;!ELEMENT ExceptionLink (Link,ExceptionName)>
			&lt;!ELEMENT ExceptionName (#PCDATA)>
			&lt;!ELEMENT MessageLink (Link)>

			&lt;!--
			 Misc properties stuff - not exactly belong to diagram, but we stick them here!
			-->
			&lt;!ELEMENT Properties (Property)*>
			&lt;!ELEMENT Property (Attributes)>
			&lt;!ATTLIST Property Name CDATA #REQUIRED>
			&lt;!ELEMENT Attributes (Attribute)*>
			&lt;!ELEMENT Attribute (Value,Desc)>
			&lt;!ATTLIST Attribute Name CDATA #REQUIRED>
			&lt;!ATTLIST Attribute Type CDATA #REQUIRED>

			&lt;!--
			 Messages Element
			-->
			&lt;!ELEMENT Messages (CommonMessages,SpecificMessages)>
			&lt;!ELEMENT CommonMessages (#PCDATA)>
			&lt;!ELEMENT SpecificMessages (Msg)*>
			&lt;!ELEMENT Msg (MsgBody, MsgExpl)>
			&lt;!ATTLIST Msg msg_key CDATA #REQUIRED>
			&lt;!ELEMENT MsgBody (#PCDATA)>
			&lt;!ELEMENT MsgExpl (#PCDATA)>
			&lt;!ATTLIST SpecificMessages locale CDATA #REQUIRED>

			]>

		</xsl:text>	

		<!-- *** Now write the real XML content for the root element CollabTemplate *** -->
		<xsl:apply-templates select="CollabTemplate" />	
	</xsl:template>

	<!-- *** the root template applies the CollabTemplate element *** -->
	<xsl:template match="CollabTemplate">
		<xsl:element name="{name()}">
		<xsl:for-each select="@*">	
			<xsl:attribute name="{name()}">
				<xsl:choose>
					<xsl:when test="name() = 'Version' or name() = 'FormatVersion'">
						<xsl:value-of select="'4.2.0'" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="." />						
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
		</xsl:for-each>		
		<xsl:value-of select="$newline" />
			<xsl:copy-of select="Header" />
			<xsl:value-of select="$newline" />
			
			<xsl:apply-templates select="TemplateDefinition" />
			<xsl:value-of select="$newline" />

			<xsl:call-template name="writeGUITemplateDefinition" />
			<xsl:value-of select="$newline" />

			<xsl:apply-templates select="Scenarios" />
			<xsl:value-of select="$newline" />

			<xsl:apply-templates select="Messages" />
			<xsl:value-of select="$newline" />
		</xsl:element>
	</xsl:template>

	<!-- *** the CollabTemplate template applies the TemplateDefinition element *** -->
	<xsl:template match="TemplateDefinition" >
		<xsl:element name="{name()}">
		<xsl:value-of select="$newline" />
			<xsl:copy-of select="Desc" />
			<xsl:value-of select="$newline" />

			<xsl:apply-templates select="Properties" />
			<xsl:value-of select="$newline" />

			<xsl:copy-of select="MinTransactionLevel" />
			<xsl:value-of select="$newline" />

			<xsl:copy-of select="Package" />
			<xsl:value-of select="$newline" />

			<xsl:copy-of select="GeneratedVars" />
			<xsl:value-of select="$newline" />

			<xsl:copy-of select="BusObjRefs" />
			<xsl:value-of select="$newline" />
		</xsl:element>
	</xsl:template>


	<!-- *** the TemplateDefinition applies the Properties element *** -->
	<xsl:template match="Properties" >
		<xsl:element name="{name()}">
		<xsl:value-of select="$newline" />
			<xsl:for-each select="Property">
				<xsl:copy-of select="." /> 						
				<xsl:value-of select="$newline" />
			</xsl:for-each>
			<!-- *** add the system property for LongLivedBusinessProcess attribute *** -->
			<xsl:element name="Property">
				<xsl:attribute name="Name">
					<xsl:value-of select="'SystemProperties'" />
				</xsl:attribute>
				<xsl:value-of select="$newline" />
				<xsl:element name="Attributes">
				<xsl:value-of select="$newline" />
					<xsl:element name="Attribute">
						<xsl:attribute name="Name">
							<xsl:value-of select="'LongLivedBusinessProcess'" />
						</xsl:attribute>
						<xsl:attribute name="Type">
							<xsl:value-of select="'0'" />
						</xsl:attribute>
						<xsl:value-of select="$newline" />
						<xsl:element name="Value">
							<xsl:value-of select="'false'" /> 
						</xsl:element>
						<xsl:element name="Desc">
							<xsl:value-of select="'Is the Template Long Lived'" />
						</xsl:element>
						<xsl:value-of select="$newline" />
					</xsl:element>
				</xsl:element>
			</xsl:element>			
		</xsl:element>	
	</xsl:template>
	

	<!-- *** the CollabTemplate template applies the Scenarios element *** -->
	<xsl:template match="Scenarios" >
		<xsl:element name="{name()}">
		<xsl:value-of select="$newline" />
			<xsl:for-each select="Scenario">
				<xsl:call-template name="writeScenario" />
				<xsl:value-of select="$newline" />
			</xsl:for-each>
		</xsl:element>	
	</xsl:template>

	<!-- *** the CollabTemplate applies the Messages element *** -->
	<xsl:template match="Messages" >
		<xsl:element name="{name()}">
		<xsl:value-of select="$newline" />

			<xsl:variable name="treeSpecificMessages">
				<xsl:variable name="strString" select="SpecificMessages" />
				<xsl:copy-of select="java:GetFormatedMessages($objXSLTUtils, $strString)" />				
			</xsl:variable>			

			<xsl:variable name="nodeSpecificMessages" select="xalan:nodeset($treeSpecificMessages)" />

			<xsl:element name="CommonMessages">
				<xsl:for-each select="$nodeSpecificMessages/Comment">
					<xsl:value-of select="." />
				</xsl:for-each>
			</xsl:element>
			<xsl:value-of select="$newline" />

			<xsl:call-template name="writeSpecificMessages" >
				<xsl:with-param name="nodeSpecificMessages" select="$nodeSpecificMessages" />
			</xsl:call-template>
			<xsl:value-of select="$newline" /> 
		</xsl:element>	
	</xsl:template>

	<!-- *** the Messages applies the SpecificMessages element *** -->
	<xsl:template name="writeSpecificMessages" >
	<xsl:param name="nodeSpecificMessages" />
		<xsl:element name="SpecificMessages">
			<xsl:attribute name="locale">
				<xsl:value-of select="'en_US'" />
			</xsl:attribute>
			<xsl:value-of select="$newline" />

			<xsl:for-each select="$nodeSpecificMessages/Msg">
				<xsl:copy-of select="." />				
			</xsl:for-each>

		</xsl:element>
	</xsl:template>

	<!-- 
	***************************************************************************************************************************************************************************
	Utility template functions.
	***************************************************************************************************************************************************************************
	-->

	<!-- *** copies all source element's attribute name and value pairs to the destination element *** -->
	<xsl:template name="writeAllAttirbutes">
		<xsl:for-each select="@*">	
			<xsl:attribute name="{name()}">
				<xsl:value-of select="." />
			</xsl:attribute>
		</xsl:for-each>
	</xsl:template>

	<!-- *** Write the new GUITemplateDefinition element *** -->
	<xsl:template name="writeGUITemplateDefinition" >
		<GUITemplateDefinition>
			<xsl:element name="GUIProperties">
				<xsl:call-template name="writeTemplateDefGUIProperties">
					<xsl:with-param name="PropertyName" select="'PropertyValues'" />
				</xsl:call-template>				
			</xsl:element>
			<GUIImports />
			<GUIUserSection1>
				<xsl:call-template name="writeUserSectionTemplateDef">
					<xsl:with-param name="PropertyName" select="'Imports'" />
				</xsl:call-template>
			</GUIUserSection1>
			<GUIUserSection2>
				<xsl:call-template name="writeUserSectionTemplateDef">
					<xsl:with-param name="PropertyName" select="'Declaration'" />
				</xsl:call-template>
			</GUIUserSection2>
			<GUIUserSection3 />
			<GUIVariables />
		</GUITemplateDefinition>
	</xsl:template>

	<!-- *** 
		Populate the GUIProperties elements of GUITemplateDefinition element 
	    depending on the valus in TemplateDefinition/Properties/Property 
	 *** -->
	<xsl:template name="writeTemplateDefGUIProperties">	
	<xsl:param name="PropertyName" />	
		<xsl:element name="GeneralProperties">	
			<xsl:for-each select="TemplateDefinition/Properties/Property[@Name = $PropertyName]/Attributes/Attribute">
				<xsl:if test="not(@Name = 'ClassName')">
					<xsl:element name="GUIProperty">
						<xsl:attribute name="Name">
							<xsl:value-of select="@Name" />
						</xsl:attribute>
						<xsl:element name="GUIPropertyType">
							<xsl:value-of select="'String'" />
						</xsl:element>
						<xsl:element name="Desc">
							<xsl:value-of select="Desc" />
						</xsl:element>
						<MaxStringLength />
						<MaxMultipleValues />
						<xsl:element name="DefaultValues">
							<Values> 
								<xsl:call-template name="WriteGUIPropertyValues">
									<xsl:with-param name="Values" select="Value" />
								</xsl:call-template>
							</Values>
							<Ranges />
						</xsl:element>
						<xsl:element name="PossibleValues">
							<Values> 
								<xsl:call-template name="WriteGUIPropertyValues">
									<xsl:with-param name="Values" select="Value" />
								</xsl:call-template>
							</Values>
							<Ranges />
						</xsl:element>
						<xsl:value-of select="$newline" />
					</xsl:element>
				</xsl:if>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>

	<!-- *** Wirte the GUIProperty values for each of the cinverted property *** -->
	<xsl:template name="WriteGUIPropertyValues">	
	<xsl:param name="Values" />	
		<xsl:variable name="firstValue" select="substring-before($Values, ',')" />
		<xsl:variable name="nextValues" select="substring-after($Values, ',')" />
		<xsl:choose>
			<xsl:when test="$firstValue = '' and $nextValues = ''">
				<xsl:if test="not($Values = '')">
				<xsl:element name="GUIPropertyValue">
					<xsl:value-of select="$Values" />
				</xsl:element>				
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="not($firstValue = '')">		
					<xsl:element name="GUIPropertyValue">
						<xsl:value-of select="$firstValue" />
					</xsl:element>
				</xsl:if>
				<xsl:if test="not($nextValues = '')">
					<xsl:call-template name="WriteGUIPropertyValues">
						<xsl:with-param name="Values" select="$nextValues" />
					</xsl:call-template>				
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>

	<!-- *** 
		Populate the user section elements of GUITemplateDefinition element 
	    depending on the valus in TemplateDefinition/Properties/Property 
	 *** -->
	<xsl:template name="writeUserSectionTemplateDef">	
	<xsl:param name="PropertyName" />		
		<xsl:for-each select="TemplateDefinition/Properties/Property[@Name = $PropertyName]/Attributes/Attribute">
			<xsl:value-of select="Value" />							
			<xsl:value-of select="$newline" />
		</xsl:for-each>
	</xsl:template>

	<!-- *** 
		Write the scenario elements of scenarios element 	    
	 *** -->
	<xsl:template name="writeScenario">	
		
		<xsl:variable name="ScenarioName" select="@Name" />
		<xsl:element name="{name()}">
		<xsl:for-each select="@*">	
			<xsl:attribute name="{name()}">
				<xsl:choose>
					<xsl:when test="name() = 'Version'">
						<xsl:value-of select="'4.2.0'" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="." />						
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
		</xsl:for-each>		
		<xsl:value-of select="$newline" />
		<xsl:copy-of select="Header" />
			<xsl:value-of select="$newline" />

			<xsl:call-template name="writeGUIDefinition" />
			<xsl:value-of select="$newline" />

			<xsl:call-template name="writeGUIDiagrams">
				<xsl:with-param name="ScenarioName" select="$ScenarioName" />
			</xsl:call-template>

			<xsl:value-of select="$newline" />

			<xsl:call-template name="writeModelScenario" />
			<xsl:value-of select="$newline" />
		</xsl:element>
	</xsl:template>

	<!-- *** 
		Write the new GUIDefinition element for each scenario element
	 *** -->
	<xsl:template name="writeGUIDefinition">	
		<GUIDefinition>
		<xsl:value-of select="$newline" />			
			<xsl:copy-of select="Desc" />
			<xsl:value-of select="$newline" />			

			<GUIUserSection1>
				<!-- *** ASSUMPTION:The first diagram in the corresponding model scenario 
				         will have the proper variable declaration in ONLY section1
				 *** -->
				<xsl:value-of select="ModelScenario/Diagram/Declaration/Section1" />			
			</GUIUserSection1>

			<GUIUserSection2 />
			<GUIVariables />
		</GUIDefinition>
	</xsl:template>

	<!-- *** 
		Write the GUIDiagrams element of Scenario element 	    
	 *** -->
	<xsl:template name="writeGUIDiagrams" >
	<xsl:param name="ScenarioName" />

		<GUIDiagrams>
		<xsl:value-of select="$newline" />
			<xsl:for-each select="GUIDiagrams/GUIDiagram">
				<xsl:call-template name="writeGUIDiagram">
					<xsl:with-param name="ScenarioName" select="$ScenarioName" />
				</xsl:call-template>
				<xsl:value-of select="$newline" />
			</xsl:for-each>
		</GUIDiagrams>

	</xsl:template>

	<!-- *** 
		Write the GUIDiagram element of GUIDiagrams element 	    
	 *** -->
	<xsl:template name="writeGUIDiagram">	
	<xsl:param name="ScenarioName" />
		
		<xsl:variable name="DiagramName" select="substring-after(@Name, 'GUI__')" />
		<xsl:element name="{name()}">
		<xsl:call-template name="writeAllAttirbutes" />
		<xsl:value-of select="$newline" />
			<xsl:copy-of select="Header" />
			<xsl:value-of select="$newline" />

			<xsl:element name="GUIProperties">
			</xsl:element>

			<xsl:copy-of select="GUISettings" />
			<xsl:value-of select="$newline" />

			<xsl:call-template name="writeNodesGUI">
				<xsl:with-param name="ScenarioName" select="$ScenarioName" />
				<xsl:with-param name="DiagramName" select="$DiagramName" />
			</xsl:call-template>
			<xsl:value-of select="$newline" />

			<xsl:call-template name="writeLinksGUI">
				<xsl:with-param name="ScenarioName" select="$ScenarioName" />
				<xsl:with-param name="DiagramName" select="$DiagramName" />
			</xsl:call-template>
			<xsl:value-of select="$newline" />

			<xsl:copy-of select="Texts" />
			<xsl:value-of select="$newline" />
		</xsl:element>
	</xsl:template>

	<!-- *** 
		Write the NodesGUI element of GUIDiagram element 	    
	 *** -->
	<xsl:template name="writeNodesGUI" >
	<xsl:param name="ScenarioName" />
	<xsl:param name="DiagramName" />

		<NodesGUI>
		<xsl:value-of select="$newline" />
			<xsl:for-each select="NodesGUI/NodeGUI">
				<xsl:call-template name="writeNodeGUI">
					<xsl:with-param name="ScenarioName" select="$ScenarioName" />
					<xsl:with-param name="DiagramName" select="$DiagramName" />
				</xsl:call-template>
				<xsl:value-of select="$newline" />
			</xsl:for-each>
		</NodesGUI>

	</xsl:template>

	<!-- *** 
		Write the NodeGUI element of NodesGUI element 	    
	 *** -->
	<xsl:template name="writeNodeGUI">	
	<xsl:param name="ScenarioName" />
	<xsl:param name="DiagramName" />

		<xsl:element name="{name()}">
		<xsl:value-of select="$newline" />
			<xsl:copy-of select="NodeLinkGUI" />
			<xsl:value-of select="$newline" />

			<xsl:copy-of select="GUICoord2" />
			<xsl:value-of select="$newline" />
		</xsl:element>

		<xsl:variable name="NodeID" select="NodeLinkGUI/@UniqIDRef" />


		<!-- *** Now see whether a decision node needs to be added after this one or not *** -->
		<xsl:if test="document($DecisionXML)/*/Scenario[name = $ScenarioName]/Diagram[name = $DiagramName]/DecisionLinkNode[SourceNodeID = $NodeID]" >
			<xsl:variable name="DecisionInfo" select="document($DecisionXML)/*/Scenario[name = $ScenarioName]/Diagram[name = $DiagramName]/DecisionLinkNode[SourceNodeID = $NodeID]" />
			<xsl:value-of select="$newline" />
			<xsl:element name="{name()}">
			<xsl:value-of select="$newline" />
				<xsl:element name="NodeLinkGUI">
					<xsl:attribute name="UniqIDRef">
						<xsl:value-of select="$DecisionInfo/NewDecisionNodeID" />
					</xsl:attribute>
					<xsl:copy-of select="NodeLinkGUI/GUIFont" />
				</xsl:element>
				<xsl:value-of select="$newline" />

				<xsl:variable name="CenterX" select="GUICoord2/GUICoord[1]/@X + ((GUICoord2/GUICoord[2]/@X - GUICoord2/GUICoord[1]/@X) div 2)" />
				<xsl:variable name="CenterY" select="GUICoord2/GUICoord[1]/@Y + ((GUICoord2/GUICoord[2]/@Y - GUICoord2/GUICoord[1]/@Y) div 2)" />

				<xsl:element name="GUICoord2" >
					<xsl:element name="GUICoord" >
						<xsl:attribute name="X">
							<xsl:value-of select="round($CenterX) - 30" />
						</xsl:attribute>
						<xsl:attribute name="Y">
							<xsl:value-of select="round($CenterY)" />
						</xsl:attribute>
					</xsl:element>
					<xsl:element name="GUICoord" >
						<xsl:attribute name="X">
							<xsl:value-of select="round($CenterX) + 30" />
						</xsl:attribute>
						<xsl:attribute name="Y">
							<xsl:value-of select="round($CenterY) + 57" />
						</xsl:attribute>
					</xsl:element>
				</xsl:element>
				<xsl:value-of select="$newline" />

				<xsl:call-template name="writeNewDecisionInfo">
					<xsl:with-param name="DecisionInfo" select="$DecisionInfo" />
				</xsl:call-template>

			</xsl:element>
		</xsl:if>
		

	</xsl:template>

	<!-- *** 
		Write the new DecisionNode element of  NodesGUI element 	    
	 *** -->
	<xsl:template name="writeNewDecisionInfo" >
	<xsl:param name="DecisionInfo" />

		<DecisionNode>
			<xsl:attribute name="UniqID">
				<xsl:value-of select="$DecisionInfo/NewDecisionNodeID" />
			</xsl:attribute>
			<xsl:value-of select="$newline" />
			<Label />
			<Desc />
			<DecisionBranches>		
				<xsl:call-template name="writeDecisonBranch">
					<xsl:with-param name="DecisionInfo" select="$DecisionInfo" />
				</xsl:call-template>
			</DecisionBranches>
		</DecisionNode>

	</xsl:template>

	<!-- *** 
		Write the new DecisionBranch element of  DecisionNode element 	    
	 *** -->
	<xsl:template name="writeDecisonBranch" >
	<xsl:param name="currentBranchIndex" select="1" />
	<xsl:param name="DecisionInfo" />

		<xsl:element name="DecisionBranch">
			<xsl:attribute name="Type">
				<xsl:value-of select="$DecisionInfo/Links/LinkInfo[$currentBranchIndex]/LinkDetails/@type" />
			</xsl:attribute>
			<xsl:value-of select="$newline" />
			<xsl:element name="Condition">
				<xsl:value-of select="$DecisionInfo/Links/LinkInfo[$currentBranchIndex]/LinkDetails/Value" />
			</xsl:element>
			<xsl:element name="Comment">
				<xsl:value-of select="$DecisionInfo/Links/LinkInfo[$currentBranchIndex]/LinkDetails/Comment" />
			</xsl:element>
			<xsl:element name="Label">
				<xsl:value-of select="$DecisionInfo/Links/LinkInfo[$currentBranchIndex]/LinkDetails/Label" />
			</xsl:element>
			<xsl:element name="LinkID">
				<xsl:value-of select="$DecisionInfo/Links/LinkInfo[$currentBranchIndex]/@ID" />
			</xsl:element>
		</xsl:element>

		<xsl:choose>
		<xsl:when test="($currentBranchIndex + 1) &lt;= count($DecisionInfo/Links/LinkInfo)">
			<xsl:call-template name="writeDecisonBranch">
				<xsl:with-param name="currentBranchIndex" select="$currentBranchIndex + 1" />
				<xsl:with-param name="DecisionInfo" select="$DecisionInfo" />
			</xsl:call-template>				
		</xsl:when>
		<xsl:when test="($currentBranchIndex + 1) &lt;= 7">
			<xsl:call-template name="writeEmptyDecisonBranch">
				<xsl:with-param name="currentBranchIndex" select="$currentBranchIndex + 1" />
			</xsl:call-template>				
		</xsl:when>		
		</xsl:choose>

	</xsl:template>

	<!-- *** 
		Write the empty DecisionBranch element of  DecisionNode element 	    
	 *** -->
	<xsl:template name="writeEmptyDecisonBranch" >
	<xsl:param name="currentBranchIndex" />

		<xsl:element name="DecisionBranch">
			<xsl:attribute name="Type">
				<xsl:value-of select="'NotUsed'" />
			</xsl:attribute>
			<xsl:value-of select="$newline" />
			<xsl:element name="Condition" />
			<xsl:element name="Comment" />
			<xsl:element name="Label" />
			<xsl:element name="LinkID" />
		</xsl:element>

		<xsl:if test="($currentBranchIndex + 1) &lt;= 7">			
			<xsl:call-template name="writeEmptyDecisonBranch">
				<xsl:with-param name="currentBranchIndex" select="$currentBranchIndex + 1" />
			</xsl:call-template>				
		</xsl:if>
		

	</xsl:template>

	<!-- *** 
		Write the LinksGUI element of GUIDiagram element 	    
	 *** -->
	<xsl:template name="writeLinksGUI" >
	<xsl:param name="ScenarioName" />
	<xsl:param name="DiagramName" />

		<LinksGUI>
		<xsl:value-of select="$newline" />
			<xsl:for-each select="LinksGUI/LinkGUI">
				<xsl:call-template name="writeLinkGUI">
					<xsl:with-param name="ScenarioName" select="$ScenarioName" />
					<xsl:with-param name="DiagramName" select="$DiagramName" />
				</xsl:call-template>
				<xsl:value-of select="$newline" />
			</xsl:for-each>
		</LinksGUI>

	</xsl:template>

	<!-- *** 
		Write the LinkGUI element of LinksGUI element 	    
	 *** -->
	<xsl:template name="writeLinkGUI">	
	<xsl:param name="ScenarioName" />
	<xsl:param name="DiagramName" />

		<xsl:variable name="NodeID" select="NodeLinkGUI/@UniqIDRef" />

		<xsl:element name="{name()}">
		<xsl:call-template name="writeAllAttirbutes" />
		<xsl:value-of select="$newline" />
			<xsl:copy-of select="NodeLinkGUI" />
			<xsl:value-of select="$newline" />

			<xsl:copy-of select="GUICoords" />
			<xsl:value-of select="$newline" />

			<xsl:variable name="sourceDecisionInfo" select="document($DecisionXML)/*/Scenario[name = $ScenarioName]/Diagram[name = $DiagramName]/DecisionLinkNode[Links/LinkInfo[@ID = $NodeID]]" />

			<xsl:if test="$sourceDecisionInfo" >
				<xsl:element name="Connect">
					<xsl:attribute name="To">
						<xsl:value-of select="$sourceDecisionInfo/Links/LinkInfo[@ID = $NodeID]/@ToID" />
					</xsl:attribute>
					<xsl:attribute name="From">
						<xsl:value-of select="$sourceDecisionInfo/NewDecisionNodeID" />
					</xsl:attribute>					
				</xsl:element>
			</xsl:if>
			

		</xsl:element>		


		<!-- *** Now see whether a decision node needs to be added after this one or not *** -->
		<xsl:if test="document($DecisionXML)/*/Scenario[name = $ScenarioName]/Diagram[name = $DiagramName]/DecisionLinkNode/Links/LinkInfo[1][@ID = $NodeID]" >
			<xsl:variable name="DecisionInfo" select="document($DecisionXML)/*/Scenario[name = $ScenarioName]/Diagram[name = $DiagramName]/DecisionLinkNode[Links/LinkInfo[@ID = $NodeID]]" />
			<xsl:value-of select="$newline" />
			<xsl:element name="{name()}">
			<xsl:call-template name="writeAllAttirbutes" />
			<xsl:value-of select="$newline" />
				<xsl:element name="NodeLinkGUI">
					<xsl:attribute name="UniqIDRef">
						<xsl:value-of select="$DecisionInfo/NewLinkNodeID" />
					</xsl:attribute>
					<xsl:copy-of select="NodeLinkGUI/GUIFont" />
				</xsl:element>
				<xsl:value-of select="$newline" />

				<xsl:copy-of select="GUICoords" />
				<xsl:value-of select="$newline" />

				<xsl:element name="Connect">
					<xsl:attribute name="To">
						<xsl:value-of select="$DecisionInfo/NewDecisionNodeID" />
					</xsl:attribute>
					<xsl:attribute name="From">
						<xsl:value-of select="$DecisionInfo/SourceNodeID" />
					</xsl:attribute>					
				</xsl:element>

				<xsl:element name="DecisionLink">
					<xsl:attribute name="UniqID">
						<xsl:value-of select="$DecisionInfo/NewLinkNodeID" />
					</xsl:attribute>
					<Label />
					<Desc />
				</xsl:element>

			</xsl:element>
		</xsl:if>		

	</xsl:template>

	<!-- *** 
		Write the ModelScenario element of Scenario element 	    
	 *** -->
	<xsl:template name="writeModelScenario" >
		<ModelScenario>
		<xsl:value-of select="$newline" />
			<xsl:for-each select="ModelScenario/Diagram">
				<xsl:call-template name="writeDiagram" />
				<xsl:value-of select="$newline" />
			</xsl:for-each>
		</ModelScenario>
	</xsl:template>

	<!-- *** 
		Write the Diagram element of ModelScenario element 	    
	 *** -->
	<xsl:template name="writeDiagram">	
		<xsl:element name="{name()}">
		<xsl:call-template name="writeAllAttirbutes" />
		<xsl:value-of select="$newline" />
			<xsl:copy-of select="ModelStructureElement" />
			<xsl:value-of select="$newline" />

			<xsl:copy-of select="Declaration" />
			<xsl:value-of select="$newline" />

			<xsl:call-template name="writeDiagramBody" />
			<xsl:value-of select="$newline" />
		</xsl:element>

	</xsl:template>

	<!-- *** 
		Write the DiagramBody element of Diagram element 	    
	 *** -->
	<xsl:template name="writeDiagramBody">	
		<DiagramBody>
		<xsl:value-of select="$newline" />
			<xsl:copy-of select="DiagramBody/ModelActivityElement" />
			<xsl:value-of select="$newline" />

			<xsl:call-template name="writeNodes" />
			<xsl:value-of select="$newline" />

			<xsl:call-template name="writeLinks" />
			<xsl:value-of select="$newline" />
		</DiagramBody>

	</xsl:template>

	<!-- *** 
		Write the Nodes element of DiagramBody element 	    
	 *** -->
	<xsl:template name="writeNodes" >
		<Nodes>
		<xsl:value-of select="$newline" />
			<xsl:variable name="ScenarioName" select="../../@Name" />	
			<xsl:variable name="DiagramName" select="@Name" />	
			<xsl:for-each select="DiagramBody/Nodes/*">
				<xsl:choose>
					<xsl:when test="name()='ServiceNode'">
						<xsl:call-template name="writeServiceNode" />
					</xsl:when>
					<xsl:when test="name()='IteratorNode'">
						<xsl:call-template name="writeIteratorNode" />
					</xsl:when>
					<xsl:when test="name()='ActionNode'">
						<xsl:call-template name="writeActionNode" />
					</xsl:when>
					<xsl:otherwise>						
						<xsl:copy-of select="." /> 						
						<xsl:value-of select="$newline" />
					</xsl:otherwise>
				</xsl:choose>				

			</xsl:for-each>
		</Nodes>
	</xsl:template>

	<!-- *** 
		Write the Links element of DiagramBody element 	    
	 *** -->
	<xsl:template name="writeLinks" >
		<Links>
		<xsl:variable name="ScenarioName" select="../../@Name" />	
		<xsl:variable name="DiagramName" select="@Name" />	
		<xsl:value-of select="$newline" />
			<xsl:for-each select="DiagramBody/Links/*">
				<xsl:copy-of select="." /> 
				<xsl:value-of select="$newline" />
			</xsl:for-each>
		</Links>
	</xsl:template>

	<!-- *** 
		Write the IteratorNode element of Diagrambody/Nodes element 	    
	 *** -->
	<xsl:template name="writeIteratorNode" >
		<xsl:element name="{name()}">
		<xsl:attribute name="Type">
			<xsl:value-of select="./IteratorType/@Type" />
		</xsl:attribute>
		<xsl:value-of select="$newline" />
			<xsl:copy-of select="CompositeNode" />
			<xsl:value-of select="$newline" />

			<xsl:copy-of select="IteratorVariable" />
			<xsl:value-of select="$newline" />

			<xsl:element name="ThruThisObject">
				<xsl:value-of select="./BusinessObj" />
			</xsl:element>

			<xsl:text disable-output-escaping="yes">
				&lt;Start>&lt;/Start>
				&lt;Condition>&lt;/Condition>
				&lt;Increment>&lt;/Increment>
			</xsl:text>
		</xsl:element>
	</xsl:template>

	<!-- *** 
		Write the ActionNode element of Diagrambody/Nodes element 	    
	 *** -->
	<xsl:template name="writeActionNode" >
		<xsl:element name="{name()}">
			<xsl:value-of select="$newline" />
			<xsl:copy-of select="ProcessStep" />
			<xsl:value-of select="$newline" />

			<xsl:element name="CodeFragment">
				<xsl:attribute name="Type">
					<xsl:value-of select="'Java'" />
				</xsl:attribute>
				<xsl:value-of select="CodeFragment" />
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<!-- *** 
		Write the ServiceNode element of Diagrambody/Nodes element 	    
	 *** -->
	<xsl:template name="writeServiceNode" >
		<xsl:element name="OutboundServiceNode">
			<xsl:attribute name="IsSync">
				<xsl:value-of select="'true'" />
			</xsl:attribute>
			<xsl:element name="{name()}">
			<xsl:value-of select="$newline" />
				<xsl:copy-of select="ProcessStep" />
				<xsl:value-of select="$newline" />

				<xsl:copy-of select="RegBusObjName" />
				<xsl:value-of select="$newline" />

				<xsl:copy-of select="RegBusObjVerb" />
				<xsl:value-of select="$newline" />

				<xsl:copy-of select="RegBusObjRefName" />
				<xsl:value-of select="$newline" />

				<xsl:copy-of select="CmpBusObjName" />
				<xsl:value-of select="$newline" />

				<xsl:copy-of select="CmpBusObjVerb" />
				<xsl:value-of select="$newline" />

				<xsl:copy-of select="CmpBusObjRefName" />
				<xsl:value-of select="$newline" />

				<xsl:text disable-output-escaping="yes">
					&lt;WaitTimeOut Type="NotUsed">&lt;/WaitTimeOut>
				</xsl:text>
			</xsl:element>
		</xsl:element>
	</xsl:template>


</xsl:stylesheet>
